/*

   file: supply.h

   The mini-module "supply" provides a centralized place 
   for allocation and deallocation of Dictionary objects.
   Users of Dictionary objects should restrict themselves
   to allocate and deallocate Dictionary object only through
   the two functions provided in this module, in order
   to cater for future implementation changes to the 
   Dictionary datastructure. 

   Revision History:

   Creation - May 12, 2003 by M. Jansen.

*/

#include "ListDictionary.h"

template <class Key, class Item>
extern Dictionary<Key, Item>* allocateDictionary(bool v, Key key, Item item);
/*
   purpose : allocate a Dictionary on the heap.

   input   : v = true <=> keys in the dictionary must be unique.
             key  - type specifier, for Key object,
             item - type specifier for Item object.
             It suffices to pass temporary objects for the type specifiers.
             i.e. call allocateDictionary(v, key(), Item())
   returns : ptr to the allocated Dictionary object.
*/

template<class Key, class Item>
extern void deallocateDictionary(Dictionary<Key, Item>* pd);
/*
   purpose : deallocates a Dictionary. 

   input   : pd ptr to the Dictionary that needs to be deallocated.
   note    : must be called for each allocated Dictionary.
*/


